@@ -1,4 +1,5 @@
 # Django settings for demo project.
+import sys
 
 DEBUG = True
 TEMPLATE_DEBUG = DEBUG
@@ -13,11 +14,13 @@ EMAIL_BACKEND = 'django.core.mail.backends.console.EmailBackend'
 DATABASES = {
     'default': {
         'ENGINE': 'django.db.backends.sqlite3',
-        'NAME': 'db.sqlite',
-        'USER': '',
-        'PASSWORD': '',
-        'HOST': '',
-        'PORT': '',
+        'NAME': ':memory:' if 'test' in sys.argv else 'db.sqlite',
+    }
+}
+
+CACHES = {
+    'default': {
+        'BACKEND': 'django.core.cache.backends.dummy.DummyCache',
     }
 }
 
@@ -113,6 +116,11 @@ TEMPLATE_DIRS = (
     # Don't forget to use absolute paths, not relative paths.
 )
 
+from django import VERSION
+
+if VERSION[:2] < (1, 6):
+    TEST_RUNNER = 'discover_runner.DiscoverRunner'
+
 INSTALLED_APPS = (
     'django.contrib.auth',
     'django.contrib.contenttypes',
@@ -121,7 +129,35 @@ INSTALLED_APPS = (
     'django.contrib.messages',
     'django.contrib.staticfiles',
     'django.contrib.admin',
-    # 'south',
     'mmc',
     'apps.test',
 )
+
+# If you have multiple cron instances, you can specify RedisLock or
+# MemcacheLock for run only one copy of management command.
+MMC_LOCK_TYPE = 'FileLock'
+
+# Settings for RedisLock
+# MMC_REDIS_CONFIG = {
+#     'host': 'localhost', 'port': 6379,
+#     'db': 0, 'password': None
+# }
+
+# Settings for MemcacheLock
+# MMC_MEMCACHED_CONFIG = {
+#     'servers': ['127.0.0.1:11211'], 'debug': 0
+# }
+
+# Mail subject, for send any errors on your script
+MMC_SUBJECT = '[MMC] Errors'
+
+# Enable sentry notification
+MMC_SENTRY_NOTIFICATION = True
+
+# Enable email notifications
+MMC_EMAIL_NOTIFICATION = True
+
+try:
+    from local_settings import *
+except ImportError:
+    pass
\ No newline at end of file
