@@ -19,3 +19,6 @@ MEMCACHED_CONFIG = get_settings('MMC_MEMCACHED_CONFIG', {
     'servers': ['127.0.0.1:11211'], 'debug': 0
 })
 LOCK_TYPE = get_settings('MMC_LOCK_TYPE', 'FileLock')
+
+SENTRY_NOTIFICATION = get_settings('MMC_SENTRY_NOTIFICATION', True)
+EMAIL_NOTIFICATION = get_settings('MMC_EMAIL_NOTIFICATION', True)
